#!/bin/bash

#==============================================================================
# java
#==============================================================================

fun_java_sourced=1

#------------------------------------------------------------------------------
# require
#------------------------------------------------------------------------------

[[ -n $fun_arch_sourced ]] || . $(dirname $BASH_SOURCE)/fun-arch.sh
export EPAGES_KERNEL

[[ -n $fun_linux_sourced ]] || . $(dirname $BASH_SOURCE)/fun-linux.sh
export chkconfig_do

#------------------------------------------------------------------------------
# provide
#------------------------------------------------------------------------------

export jre_home java_executable mongod_name start_mongodb

#------------------------------------------------------------------------------
# define
# -----------------------------------------------------------------------------

#..............................................................................
# jre_home
#..............................................................................

jre_home() {
  local USAGE='
syntax: jre_home
returns: path to JRE directory
'
  [[ $# = 0 ]] || { echo "$USAGE" 1>&2; return 1; }
  local JRE EPAGES_JAVA EPAGES_JAVA7 EPAGES_JAVA6

  for i in /usr/java/latest /etc/alternatives ; do
    EPAGES_JAVA=$(readlink -f $i/jre)
    [[ -d $EPAGES_JAVA ]] || continue
    [[ $EPAGES_JAVA = ${EPAGES_JAVA#*java-[78]} ]] || { echo $i/jre; return; }
    [[ $EPAGES_JAVA = ${EPAGES_JAVA#*java-1.[78]} ]] || { echo $i/jre; return; }
  done

  if [[ $EPAGES_KERNEL != ${EPAGES_KERNEL%s} && -n $EPAGES_JAVA ]] ; then
    # for SuSE linux return if $EPAGES_JAVA/jre exists
    [[ -d $EPAGES_JAVA/jre ]] && { echo /usr/java/latest/jre; return; }
  fi

  for LIB in /usr/lib64 /usr/lib ; do
    EPAGES_JAVA=$(ls -dv $LIB*/jvm/java-*/jre 2>/dev/null)
    EPAGES_JAVA6=$(echo "$EPAGES_JAVA" | sort | tail -1)
    EPAGES_JAVA7=$(echo "$EPAGES_JAVA" | egrep 'java-(1\.)?[78]' | sort | tail -1)
    [[ -n $EPAGES_JAVA7 ]] && { echo $EPAGES_JAVA7; return; }
    [[ -n $JRE_HOME && -d $JRE_HOME ]] && { echo $JRE_HOME; return; }

    EPAGES_JAVA=$(ls -dv $LIB*/jvm/jre 2>/dev/null)
    EPAGES_JAVA6=$(echo "$EPAGES_JAVA" | sort | tail -1)
    EPAGES_JAVA7=$(echo "$EPAGES_JAVA" | egrep 'java-(1\.)?[78]' | sort | tail -1)
    [[ -n $EPAGES_JAVA7 ]] && { echo $EPAGES_JAVA7; return; }
  done

  [[ -n $EPAGES_JAVA6 ]] && { echo $EPAGES_JAVA6; return; }
}

#..............................................................................
# java_executable
#..............................................................................

java_executable() {
  local USAGE='
syntax: java_executable
returns: java executable path
'
  [[ $# = 0 ]] || { echo "$USAGE" 1>&2; return 1; }

  EPAGES_JAVA="$(jre_home)"
  [ -x "$EPAGES_JAVA"/bin/java ] && { echo "$EPAGES_JAVA"/bin/java; return 0; } 
  [ -z "$EPAGES_JAVA" ] && { type -p java; return $?; }
  JAVA_HOME="$(dirname "$(readlink -f $EPAGES_JAVA)")"
  [ -x "$JAVA_HOME"/bin/java ] && { echo "$JAVA_HOME"/bin/java; return 0; } 
  type -p java
  return $?
}

#..............................................................................
# mongod_name
#..............................................................................
mongod_name () {
  local USAGE='
syntax: mongod_name
description: return name of mongod as in init script
'
  [[ $# = 0 ]] || { echo "$USAGE" 1>&2; return 1; }
  if [[ -f /etc/debian_version ]] ; then
    [[ -x /etc/init.d/mongodb ]] && echo mongodb
  elif grep -q epages /etc/init.d/mongod 2>/dev/null ; then
    echo mongod
  fi
}

#..............................................................................
# start_mongodb
#..............................................................................
start_mongodb () {
  local USAGE='
syntax: start_mongodb
description: adds and starts mongod service
'
  [[ $# = 0 ]] || { echo "$USAGE" 1>&2; return 1; }

  if [[ ! -f /etc/debian_version ]] ; then
    [[ -x /etc/init.d/$(mongod_name) ]] && /etc/init.d/$(mongod_name) stop >/dev/null 2>&1
    pkill -9 -f /usr/bin/mongod

    cp -p /var/epages/mongod /etc/init.d

    if [ -f /etc/SuSE-release -a -f /etc/init.d/jexec ] ; then
      grep -q '^# Required-Stop:' /etc/init.d/jexec || {
        sed -i '/^# Required-Start:/a\
# Required-Stop:' /etc/init.d/jexec
      }
    fi

    chmod 750 /etc/init.d/mongod
    sed -i 's,chkconfig: -,chkconfig: 35,' /etc/init.d/mongod
    chkconfig_do --del mongod mongodb >/dev/null 2>&1
    chkconfig_do --add mongod >/dev/null 2>&1
    /etc/init.d/mongod stop >/dev/null 2>&1
  fi

  [[ -x /etc/init.d/$(mongod_name) ]] && /etc/init.d/$(mongod_name) start
}

#------------------------------------------------------------------------------
# end
# -----------------------------------------------------------------------------
